<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="Kiten Dictionary Editor" version="2">

<MenuBar>
<Menu name="file"><text>&amp;File</text>
  <Action name="disable"/>
</Menu>

<Menu name="edit"><text>&amp;Edit</text>
  <Action name="add" />
  <Action name="del" />
</Menu>

</MenuBar>

<ToolBar name="mainToolBar" fullWidth="true"><text>Main Toolbar</text>
  <Action name="add" />
  <Action name="del" />
</ToolBar>

</kpartgui>
