<!DOCTYPE kpartgui>
<kpartgui name="kalzium">
<MenuBar>
<Menu name="calculations"><text>&amp;Operations</text>
        <Action name="calculations"/>
        <Action name="startplotting"/>
        <Action name="searchdata"/>
</Menu>

<Menu name="quiz"><text>&amp;Quiz</text>
        <Action name="test_your_knowledge"/>
</Menu>

<Menu name="view"><text>&amp;View</text>
        <Action name="psestyle"/>
        <Action name="colorscheme"/>
        <Action name="numeration"/>
        <Separator/>
        <Action name="timeline"/>
        <Action name="quickinfo"/>
        <Action name="legend"/>

</Menu>


</MenuBar>

<ToolBar name="mainToolBar" noMerge="1" position="top"><text>Main</text>
        <Action name="psestyle"/>
        <Action name="colorscheme"/>
        <Action name="numeration"/>
        <Action name="timeline"/>
        <Action name="quickinfo"/>
        <Action name="legend"/>
</ToolBar>

</kpartgui>
