<!DOCTYPE kpartgui>
<kpartgui name="kverbos" version="6">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="file_open_standard" append="new_merge"/>
    <Action name="file_new_window"/>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="edit_erfassen"/>
    <Action name="edit_bearbeiten"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="settings_options" append="configure_merge"/>
  </Menu>
  <Menu name="user"><text>&amp;User</text>
    <Action name="user_username"/>
    <Action name="user_results"/>
  </Menu>
</MenuBar>
</kpartgui>

