<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="klettres" version="3">
<MenuBar>
	<Menu name="file" noMerge="1"><text>&amp;File</text>
		<Action name="file_quit"/>
	</Menu>

        <Action name="languages"/>

	<Menu name="settings" noMerge="1"><text>&amp;Settings</text>
		<Action name="menubar" />
		<Merge name="StandardToolBarMenuHandler" />
		<Action name="options_show_statusbar"/>
		<Separator/>
		<Action name="font"/>
		<Action name="options_configure_keybinding"/>
		<Action name="options_configure_toolbars"/>

	</Menu>
</MenuBar>
<ToolBar name="mainToolBar" noMerge="1"><Text>Main</Text>
	<Action name="file_quit"/>
    	<Separator/>
    	<Action name="help_contents"/>
</ToolBar>
<ToolBar name="secondToolbar" position="bottom" noMerge="1"><text>Characters</text>
</ToolBar>
</kpartgui>
