<!DOCTYPE kpartgui>
<kpartgui name="flashkard" version="3">

<MenuBar>
	<Menu name="Function"><text>F&amp;unction</text>
		<Action name="showData"/>
		<Action name="showQuiz"/>
	</Menu>
	<Menu name="settings">
		<Action name="selectQuizMode" append="save_merge"/>
		<Action name="showAnswerLength" append="save_merge"/>
		<Action name="reverseFrontBack" append="save_merge"/>
	</Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
	<Action name="file_new"/>
	<Action name="file_open"/>
	<Action name="openDir"/>
	<Action name="file_save"/>
	<Separator lineSeparator="true"/>
	<Action name="edit_cut"/>
	<Action name="edit_copy"/>
	<Action name="edit_paste"/>
	<Separator lineSeparator="true"/>
	<Action name="showData"/>
	<Action name="showQuiz"/>
</ToolBar>

</kpartgui>
